@@ -74,6 +74,7 @@ class FunctionModule(SchemaChildModule):
         self.min_ver = 90100
         self.max_ver = None
         self.server_type = None
+        self.min_gpdbver = 1000000000
 
     def get_nodes(self, gid, sid, did, scid):
         """
@@ -436,9 +437,14 @@ class FunctionView(PGChildNodeView, DataTypeReader):
         """
 
         resp_data = self._fetch_properties(gid, sid, did, scid, fnid)
+        # Most probably this is due to error
+        if not isinstance(resp_data, dict):
+            return resp_data
 
         if len(resp_data) == 0:
-            return gone(gettext("""Could not find the function node in the database."""))
+            return gone(
+                gettext("Could not find the function node in the database.")
+            )
 
         return ajax_response(
             response=resp_data,
@@ -871,6 +877,9 @@ class FunctionView(PGChildNodeView, DataTypeReader):
                 return internal_server_error(errormsg=res)
 
             resp_data = self._fetch_properties(gid, sid, did, scid, fnid)
+            # Most probably this is due to error
+            if not isinstance(resp_data, dict):
+                return resp_data
 
             if self.node_type == 'procedure':
                 obj_name = resp_data['name_with_args']
@@ -916,11 +925,16 @@ class FunctionView(PGChildNodeView, DataTypeReader):
             fnid: Function Id
         """
         resp_data = self._fetch_properties(gid, sid, did, scid, fnid)
+        # Most probably this is due to error
+        if not isinstance(resp_data, dict):
+            return resp_data
+
         # Fetch the function definition.
         args = u''
         args_without_name = []
         cnt = 1
         args_list = []
+        vol_dict = {'v': 'VOLATILE', 's': 'STABLE', 'i': 'IMMUTABLE'}
 
         if 'arguments' in resp_data and len(resp_data['arguments']) > 0:
             args_list = resp_data['arguments']
@@ -949,6 +963,10 @@ class FunctionView(PGChildNodeView, DataTypeReader):
 
         if self.node_type == 'procedure':
             object_type = 'procedure'
+            if 'provolatile' in resp_data:
+                resp_data['provolatile'] = vol_dict.get(
+                    resp_data['provolatile'], ''
+                )
 
             # Get Schema Name from its OID.
             if 'pronamespace' in resp_data:
@@ -971,6 +989,9 @@ class FunctionView(PGChildNodeView, DataTypeReader):
             if 'acl' in resp_data:
                 resp_data['acl'] = parse_priv_to_db(resp_data['acl'], ['X'])
 
+                # Check Revoke all for public
+                resp_data['revoke_all'] = self._set_revoke_all(resp_data['acl'])
+
             # Generate sql for "SQL panel"
             # func_def is procedure signature with default arguments
             # query_for - To distinguish the type of call
@@ -991,6 +1012,9 @@ class FunctionView(PGChildNodeView, DataTypeReader):
             if 'acl' in resp_data:
                 resp_data['acl'] = parse_priv_to_db(resp_data['acl'], ['X'])
 
+                # Check Revoke all for public
+                resp_data['revoke_all'] = self._set_revoke_all(resp_data['acl'])
+
             SQL = render_template("/".join([self.sql_template_path,
                                             'get_definition.sql']
                                            ), data=resp_data,
@@ -1087,6 +1111,11 @@ class FunctionView(PGChildNodeView, DataTypeReader):
 
             # Fetch Old Data from database.
             old_data = self._fetch_properties(gid, sid, did, scid, fnid)
+            # Most probably this is due to error
+            if not isinstance(old_data, dict):
+                return False, gettext(
+                    "Could not find the function in the database."
+                )
 
             # Get Schema Name
             old_data['pronamespace'] = self._get_schema(old_data[
@@ -1193,6 +1222,9 @@ class FunctionView(PGChildNodeView, DataTypeReader):
             if 'acl' in data:
                 data['acl'] = parse_priv_to_db(data['acl'], ["X"])
 
+                # Check Revoke all for public
+                data['revoke_all'] = self._set_revoke_all(data['acl'])
+
             args = u''
             args_without_name = []
             cnt = 1
@@ -1250,10 +1282,9 @@ class FunctionView(PGChildNodeView, DataTypeReader):
             return internal_server_error(errormsg=res)
 
         if len(res['rows']) == 0:
-            return gone(gettext("""
-Could not find the function in the database.\n
-It may have been removed by another user or moved to another schema.
-"""))
+            return gone(
+                gettext("Could not find the function in the database.")
+            )
 
         resp_data = res['rows'][0]
 
@@ -1304,6 +1335,19 @@ It may have been removed by another user or moved to another schema.
 
         return schema_name
 
+    def _set_revoke_all(self, privileges):
+        """
+        Check whether the function requires REVOKE statement
+        for PUBLIC or not.
+        """
+        revoke_all = True if len(privileges) > 0 else False
+        for p in privileges:
+            if p['grantee'] == 'PUBLIC':
+                revoke_all = False
+                break;
+
+        return revoke_all
+
     @check_precondition
     def dependents(self, gid, sid, did, scid, fnid):
         """
@@ -1393,6 +1437,9 @@ It may have been removed by another user or moved to another schema.
             doid: Function Id
         """
         resp_data = self._fetch_properties(gid, sid, did, scid, fnid)
+        # Most probably this is due to error
+        if not isinstance(resp_data, dict):
+            return resp_data
 
         # Fetch the schema name from OID
         if 'pronamespace' in resp_data:
@@ -1504,6 +1551,7 @@ class ProcedureModule(SchemaChildModule):
 
         self.min_ver = 90100
         self.max_ver = None
+        self.min_gpdbver = 1000000000
         self.server_type = ['ppas']
 
     def get_nodes(self, gid, sid, did, scid):
@@ -1615,6 +1663,7 @@ class TriggerFunctionModule(SchemaChildModule):
 
         self.min_ver = 90100
         self.max_ver = None
+        self.min_gpdbver = 1000000000
 
     def get_nodes(self, gid, sid, did, scid):
         """
